@@ -1,18 +1,20 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+   You should have received a copy of the GNU General Public License
+   along with this program; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include "followupremindercreatejob.h"
@@ -29,22 +31,21 @@ public:
     FollowupReminderCreateJobPrivate()
         : mInfo(new FollowUpReminder::FollowUpReminderInfo)
     {
-
     }
+
     ~FollowupReminderCreateJobPrivate()
     {
         delete mInfo;
     }
 
     Akonadi::Collection mCollection;
-    FollowUpReminder::FollowUpReminderInfo *mInfo;
+    FollowUpReminder::FollowUpReminderInfo *mInfo = nullptr;
 };
 
 FollowupReminderCreateJob::FollowupReminderCreateJob(QObject *parent)
-    : KJob(parent),
-      d(new MessageComposer::FollowupReminderCreateJobPrivate)
+    : KJob(parent)
+    , d(new MessageComposer::FollowupReminderCreateJobPrivate)
 {
-
 }
 
 FollowupReminderCreateJob::~FollowupReminderCreateJob()
@@ -87,7 +88,7 @@ void FollowupReminderCreateJob::start()
     if (d->mInfo->isValid()) {
         if (d->mCollection.isValid()) {
             KCalCore::Todo::Ptr todo(new KCalCore::Todo);
-            todo->setSummary(i18n("Wait answer from \"%1\" send to \"%2\"").arg(d->mInfo->subject()).arg(d->mInfo->to()));
+            todo->setSummary(i18n("Wait answer from \"%1\" send to \"%2\"", d->mInfo->subject(), d->mInfo->to()));
             Akonadi::Item newTodoItem;
             newTodoItem.setMimeType(KCalCore::Todo::todoMimeType());
             newTodoItem.setPayload<KCalCore::Todo::Ptr>(todo);
@@ -99,7 +100,7 @@ void FollowupReminderCreateJob::start()
         }
     } else {
         qCDebug(MESSAGECOMPOSER_LOG) << "FollowupReminderCreateJob info not valid ";
-        Q_EMIT emitResult();
+        emitResult();
         return;
     }
 }
@@ -118,5 +119,5 @@ void FollowupReminderCreateJob::slotCreateNewTodo(KJob *job)
 void FollowupReminderCreateJob::writeFollowupReminderInfo()
 {
     FollowUpReminder::FollowUpReminderUtil::writeFollowupReminderInfo(FollowUpReminder::FollowUpReminderUtil::defaultConfig(), d->mInfo, true);
-    Q_EMIT emitResult();
+    emitResult();
 }
