@@ -1,4 +1,6 @@
-/* Copyright 2009 Thomas McGuire <mcguire@kde.org>
+/*
+   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright 2009 Thomas McGuire <mcguire@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -27,7 +29,6 @@
 #include <KEmailAddress>
 #include <KLocalizedString>
 
-#include <KConfigGroup>
 #include "messagecore_debug.h"
 #include <KUser>
 
@@ -35,6 +36,7 @@
 #include <KIdentityManagement/Identity>
 #include <QHostInfo>
 #include <QRegExp>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QUrlQuery>
 #include <kpimtextedit/textutils.h>
@@ -43,12 +45,8 @@ using namespace KMime;
 using namespace KMime::Types;
 using namespace KMime::HeaderParsing;
 
-namespace MessageCore
-{
-
-namespace StringUtil
-{
-
+namespace MessageCore {
+namespace StringUtil {
 // Removes trailing spaces and tabs at the end of the line
 static void removeTrailingSpace(QString &line)
 {
@@ -75,8 +73,8 @@ static QString splitLine(QString &line)
     const int lineLength(line.length());
     while (i < lineLength) {
         const QChar c = line[i];
-        const bool isAllowedQuoteChar = (c == QLatin1Char('>')) || (c == QLatin1Char(':')) || (c == QLatin1Char('|')) ||
-                                        (c == QLatin1Char(' ')) || (c == QLatin1Char('\t'));
+        const bool isAllowedQuoteChar = (c == QLatin1Char('>')) || (c == QLatin1Char(':')) || (c == QLatin1Char('|'))
+                                        || (c == QLatin1Char(' ')) || (c == QLatin1Char('\t'));
         if (isAllowedQuoteChar) {
             startOfActualText = i + 1;
         } else {
@@ -126,8 +124,7 @@ static QString splitLine(QString &line)
 // together with a previously broken line.
 //
 // "textParts" is cleared upon return.
-static bool flushPart(QString &msg, QStringList &textParts,
-                      const QString &indent, int maxLength)
+static bool flushPart(QString &msg, QStringList &textParts, const QString &indent, int maxLength)
 {
     if (maxLength < 20) {
         maxLength = 20;
@@ -139,8 +136,8 @@ static bool flushPart(QString &msg, QStringList &textParts,
     }
 
     QString text;
-    foreach (const QString &line, textParts) {
 
+    for (const QString &line : textParts) {
         // An empty line in the input means that an empty line should be in the output as well.
         // Therefore, we write all of our text so far to the msg.
         if (line.isEmpty()) {
@@ -182,8 +179,8 @@ QMap<QString, QString> parseMailtoUrl(const QUrl &url)
         return values;
     }
     QUrlQuery query(url);
-    Q_FOREACH (const auto &queryItem, query.queryItems()) {
-        values.insert(queryItem.first, queryItem.second);
+    Q_FOREACH (const auto &queryItem, query.queryItems(QUrl::FullyDecoded)) {
+        values.insertMulti(queryItem.first, queryItem.second);
     }
 
     QStringList to;
@@ -202,9 +199,9 @@ QString stripSignature(const QString &msg)
 {
     // Following RFC 3676, only > before --
     // I prefer to not delete a SB instead of delete good mail content.
-    const QRegExp sbDelimiterSearch = QRegExp(QLatin1String("(^|\n)[> ]*-- \n"));
+    const QRegularExpression sbDelimiterSearch(QStringLiteral("(^|\n)[> ]*-- \n"));
     // The regular expression to look for prefix change
-    const QRegExp commonReplySearch = QRegExp(QLatin1String("^[ ]*>"));
+    const QRegularExpression commonReplySearch(QStringLiteral("^[ ]*>"));
 
     QString res = msg;
     int posDeletingStart = 1; // to start looking at 0
@@ -239,9 +236,9 @@ QString stripSignature(const QString &msg)
             // check when the SB ends:
             // * does not starts with prefix or
             // * starts with prefix+(any substring of prefix)
-            if ((prefix.isEmpty() && line.indexOf(commonReplySearch) < 0) ||
-                    (!prefix.isEmpty() && line.startsWith(prefix) &&
-                     line.mid(prefix.size()).indexOf(commonReplySearch) < 0)) {
+            if ((prefix.isEmpty() && line.indexOf(commonReplySearch) < 0)
+                || (!prefix.isEmpty() && line.startsWith(prefix)
+                    && line.mid(prefix.size()).indexOf(commonReplySearch) < 0)) {
                 posNewLine = res.indexOf(QLatin1Char('\n'), posNewLine) + 1;
             } else {
                 break;    // end of the SB
@@ -293,153 +290,6 @@ QString generateMessageId(const QString &address, const QString &suffix)
     return msgIdStr;
 }
 
-QString stripEmailAddr(const QString &aStr)
-{
-    //qCDebug(MESSAGECORE_LOG) << "(" << aStr << ")";
-
-    if (aStr.isEmpty()) {
-        return QString();
-    }
-
-    QString result;
-
-    // The following is a primitive parser for a mailbox-list (cf. RFC 2822).
-    // The purpose is to extract a displayable string from the mailboxes.
-    // Comments in the addr-spec are not handled. No error checking is done.
-
-    QString name;
-    QString comment;
-    QString angleAddress;
-    enum { TopLevel, InComment, InAngleAddress } context = TopLevel;
-    bool inQuotedString = false;
-    int commentLevel = 0;
-
-    QChar ch;
-    int strLength(aStr.length());
-    for (int index = 0; index < strLength; ++index) {
-        ch = aStr[index];
-        switch (context) {
-        case TopLevel : {
-            switch (ch.toLatin1()) {
-            case '"' : inQuotedString = !inQuotedString;
-                break;
-            case '(' : if (!inQuotedString) {
-                    context = InComment;
-                    commentLevel = 1;
-                } else {
-                    name += ch;
-                }
-                break;
-            case '<' : if (!inQuotedString) {
-                    context = InAngleAddress;
-                } else {
-                    name += ch;
-                }
-                break;
-            case '\\' : // quoted character
-                ++index; // skip the '\'
-                if (index < aStr.length()) {
-                    name += aStr[index];
-                }
-                break;
-            case ',' : if (!inQuotedString) {
-                    // next email address
-                    if (!result.isEmpty()) {
-                        result += QLatin1String(", ");
-                    }
-                    name = name.trimmed();
-                    comment = comment.trimmed();
-                    angleAddress = angleAddress.trimmed();
-                    if (angleAddress.isEmpty() && !comment.isEmpty()) {
-                        // handle Outlook-style addresses like
-                        // john.doe@invalid (John Doe)
-                        result += comment;
-                    } else if (!name.isEmpty()) {
-                        result += name;
-                    } else if (!comment.isEmpty()) {
-                        result += comment;
-                    } else if (!angleAddress.isEmpty()) {
-                        result += angleAddress;
-                    }
-                    name.clear();
-                    comment.clear();
-                    angleAddress.clear();
-                } else {
-                    name += ch;
-                }
-                break;
-            default :  name += ch;
-            }
-            break;
-        }
-        case InComment : {
-            switch (ch.toLatin1()) {
-            case '(' : ++commentLevel;
-                comment += ch;
-                break;
-            case ')' : --commentLevel;
-                if (commentLevel == 0) {
-                    context = TopLevel;
-                    comment += QLatin1Char(' '); // separate the text of several comments
-                } else {
-                    comment += ch;
-                }
-                break;
-            case '\\' : // quoted character
-                ++index; // skip the '\'
-                if (index < aStr.length()) {
-                    comment += aStr[index];
-                }
-                break;
-            default :  comment += ch;
-            }
-            break;
-        }
-        case InAngleAddress : {
-            switch (ch.toLatin1()) {
-            case '"' : inQuotedString = !inQuotedString;
-                angleAddress += ch;
-                break;
-            case '>' : if (!inQuotedString) {
-                    context = TopLevel;
-                } else {
-                    angleAddress += ch;
-                }
-                break;
-            case '\\' : // quoted character
-                ++index; // skip the '\'
-                if (index < aStr.length()) {
-                    angleAddress += aStr[index];
-                }
-                break;
-            default :  angleAddress += ch;
-            }
-            break;
-        }
-        } // switch ( context )
-    }
-    if (!result.isEmpty()) {
-        result += QLatin1String(", ");
-    }
-    name = name.trimmed();
-    comment = comment.trimmed();
-    angleAddress = angleAddress.trimmed();
-    if (angleAddress.isEmpty() && !comment.isEmpty()) {
-        // handle Outlook-style addresses like
-        // john.doe@invalid (John Doe)
-        result += comment;
-    } else if (!name.isEmpty()) {
-        result += name;
-    } else if (!comment.isEmpty()) {
-        result += comment;
-    } else if (!angleAddress.isEmpty()) {
-        result += angleAddress;
-    }
-
-    //qCDebug(MESSAGECORE_LOG) << "Returns \"" << result << "\"";
-    return result;
-}
-
 QString quoteHtmlChars(const QString &str, bool removeLineBreaks)
 {
     QString result;
@@ -525,22 +375,21 @@ QByteArray headerAsSendableString(const KMime::Message::Ptr &originalMessage)
     return message->head();
 }
 
-QString emailAddrAsAnchor(const KMime::Types::Mailbox::List &mailboxList,
-                          Display display, const QString &cssStyle,
-                          Link link, AddressMode expandable, const QString &fieldName,
-                          int collapseNumber)
+QString emailAddrAsAnchor(const KMime::Types::Mailbox::List &mailboxList, Display display, const QString &cssStyle, Link link, AddressMode expandable, const QString &fieldName, int collapseNumber)
 {
     QString result;
     int numberAddresses = 0;
     bool expandableInserted = false;
-    KIdentityManagement::IdentityManager im(true);
+    KIdentityManagement::IdentityManager *im = KIdentityManagement::IdentityManager::self();
 
-    foreach (const KMime::Types::Mailbox &mailbox, mailboxList) {
+    for (const KMime::Types::Mailbox &mailbox : mailboxList) {
         if (!mailbox.prettyAddress().isEmpty()) {
             numberAddresses++;
             if (expandable == ExpandableAddresses && !expandableInserted && numberAddresses > collapseNumber) {
                 result = QLatin1String("<span id=\"icon") + fieldName + QLatin1String("\"></span>") + result;
-                result += QLatin1String("<span id=\"dots") + fieldName + QLatin1String("\">...</span><span id=\"hidden") + fieldName + QLatin1String("\">");
+                const QString visibility = QStringLiteral(" style=\"display:none;\"");
+
+                result += QLatin1String("<span id=\"dots") + fieldName + QLatin1String("\">...</span><span id=\"hidden") + fieldName + QLatin1String("\")") + visibility + QLatin1String(">");
                 expandableInserted = true;
             }
 
@@ -549,7 +398,7 @@ QString emailAddrAsAnchor(const KMime::Types::Mailbox::List &mailboxList,
                           + QString::fromLatin1(QUrl::toPercentEncoding(KEmailAddress::encodeMailtoUrl(mailbox.prettyAddress(KMime::Types::Mailbox::QuoteWhenNecessary)).path()))
                           + QLatin1String("\" ") + cssStyle + QLatin1Char('>');
             }
-            const bool foundMe = (im.identities().count() == 1) && (im.identityForAddress(mailbox.prettyAddress()) != KIdentityManagement::Identity::null());
+            const bool foundMe = (im->identities().count() == 1) && (im->identityForAddress(mailbox.prettyAddress()) != KIdentityManagement::Identity::null());
             const QString i18nMe = i18nc("signal that this email is defined in my identity", "Me");
             if (display == DisplayNameOnly) {
                 if (!mailbox.name().isEmpty()) { // Fallback to the email address when the name is not set.
@@ -577,26 +426,19 @@ QString emailAddrAsAnchor(const KMime::Types::Mailbox::List &mailboxList,
     return result;
 }
 
-QString emailAddrAsAnchor(KMime::Headers::Generics::MailboxList *mailboxList,
-                          Display display, const QString &cssStyle,
-                          Link link, AddressMode expandable, const QString &fieldName,
-                          int collapseNumber)
+QString emailAddrAsAnchor(KMime::Headers::Generics::MailboxList *mailboxList, Display display, const QString &cssStyle, Link link, AddressMode expandable, const QString &fieldName, int collapseNumber)
 {
     Q_ASSERT(mailboxList);
     return emailAddrAsAnchor(mailboxList->mailboxes(), display, cssStyle, link, expandable, fieldName, collapseNumber);
 }
 
-QString emailAddrAsAnchor(KMime::Headers::Generics::AddressList *addressList,
-                          Display display, const QString &cssStyle,
-                          Link link, AddressMode expandable, const QString &fieldName,
-                          int collapseNumber)
+QString emailAddrAsAnchor(KMime::Headers::Generics::AddressList *addressList, Display display, const QString &cssStyle, Link link, AddressMode expandable, const QString &fieldName, int collapseNumber)
 {
     Q_ASSERT(addressList);
     return emailAddrAsAnchor(addressList->mailboxes(), display, cssStyle, link, expandable, fieldName, collapseNumber);
 }
 
-bool addressIsInAddressList(const QString &address,
-                            const QStringList &addresses)
+bool addressIsInAddressList(const QString &address, const QStringList &addresses)
 {
     const QString addrSpec = KEmailAddress::extractEmailAddress(address);
 
@@ -646,8 +488,25 @@ QString smartQuote(const QString &msg, int maxLineLength)
     QString oldIndent;
     bool firstPart = true;
     QString result;
-    foreach (QString line, msg.split(QLatin1Char('\n'))) {
 
+    int lineStart = 0;
+    int lineEnd = msg.indexOf(QLatin1Char('\n'));
+    bool needToContinue = true;
+    for (; needToContinue; lineStart = lineEnd + 1, lineEnd = msg.indexOf(QLatin1Char('\n'), lineStart)) {
+        QString line;
+        if (lineEnd == -1) {
+            if (lineStart == 0) {
+                line = msg;
+                needToContinue = false;
+            } else if (lineStart != 0 && lineStart != msg.length()) {
+                line = msg.mid(lineStart, msg.length() - lineStart);
+                needToContinue = false;
+            } else {
+                needToContinue = false;
+            }
+        } else {
+            line = msg.mid(lineStart, lineEnd - lineStart);
+        }
         // Split off the indent from the line
         const QString indent = splitLine(line);
 
@@ -666,7 +525,6 @@ QString smartQuote(const QString &msg, int maxLineLength)
         // The indent changed, that means we have to write everything contained in textParts to the
         // result, which we do by calling flushPart().
         if (oldIndent != indent) {
-
             // Check if the last non-blank line is a "From" line. A from line is the line containing the
             // attribution to a quote, e.g. "Yesterday, you wrote:". We'll just check for the last colon
             // here, to simply things.
@@ -675,16 +533,16 @@ QString smartQuote(const QString &msg, int maxLineLength)
             QString fromLine;
             if (!textParts.isEmpty()) {
                 for (int i = textParts.count() - 1; i >= 0; i--) {
-
                     // Check if we have found the From line
-                    if (textParts[i].endsWith(QLatin1Char(':'))) {
-                        fromLine = oldIndent + textParts[i] + QLatin1Char('\n');
+                    const QString textPartElement(textParts[i]);
+                    if (textPartElement.endsWith(QLatin1Char(':'))) {
+                        fromLine = oldIndent + textPartElement + QLatin1Char('\n');
                         textParts.removeAt(i);
                         break;
                     }
 
                     // Abort on first non-empty line
-                    if (!textParts[i].trimmed().isEmpty()) {
+                    if (!textPartElement.trimmed().isEmpty()) {
                         break;
                     }
                 }
@@ -735,17 +593,18 @@ QString formatQuotePrefix(const QString &wildString, const QString &fromDisplayS
         if (ch == QLatin1Char('%') && i < strLength) {
             ch = wildString[i++];
             switch (ch.toLatin1()) {
-            case 'f': { // sender's initals
+            case 'f':
+            {           // sender's initals
                 if (fromDisplayString.isEmpty()) {
                     break;
                 }
 
                 uint j = 0;
                 const unsigned int strLength(fromDisplayString.length());
-                for (; j < strLength && fromDisplayString[j] > QLatin1Char(' '); ++j)
-                    ;
-                for (; j < strLength && fromDisplayString[j] <= QLatin1Char(' '); ++j)
-                    ;
+                for (; j < strLength && fromDisplayString[j] > QLatin1Char(' '); ++j) {
+                }
+                for (; j < strLength && fromDisplayString[j] <= QLatin1Char(' '); ++j) {
+                }
                 result += fromDisplayString[0];
                 if (j < strLength && fromDisplayString[j] > QLatin1Char(' ')) {
                     result += fromDisplayString[j];
@@ -754,8 +613,8 @@ QString formatQuotePrefix(const QString &wildString, const QString &fromDisplayS
                         result += fromDisplayString[1];
                     }
                 }
+                break;
             }
-            break;
             case '_':
                 result += QLatin1Char(' ');
                 break;
@@ -813,11 +672,11 @@ QString cleanFileName(const QString &name)
 QString stripOffPrefixes(const QString &subject)
 {
     static QStringList defaultReplyPrefixes = QStringList() << QStringLiteral("Re\\s*:")
-            << QStringLiteral("Re\\[\\d+\\]:")
-            << QStringLiteral("Re\\d+:");
+                                                            << QStringLiteral("Re\\[\\d+\\]:")
+                                                            << QStringLiteral("Re\\d+:");
 
     static QStringList defaultForwardPrefixes = QStringList() << QStringLiteral("Fwd:")
-            << QStringLiteral("FW:");
+                                                              << QStringLiteral("FW:");
 
     QStringList replyPrefixes = MessageCoreSettings::self()->replyPrefixes();
     if (replyPrefixes.isEmpty()) {
@@ -864,8 +723,5 @@ void setEncodingFile(QUrl &url, const QString &encoding)
 {
     url.addQueryItem(QStringLiteral("charset"), encoding);
 }
-
 }
-
 }
-
