@@ -34,7 +34,7 @@ Filter::Filter(QObject *parent)
 bool Filter::containString(const QString &searchInString) const
 {
     bool found = false;
-    Q_FOREACH (const QString &str, mSearchList) {
+    for (const QString &str : qAsConst(mSearchList)) {
         if (searchInString.contains(str, Qt::CaseInsensitive)) {
             found = true;
         } else {
@@ -48,7 +48,7 @@ bool Filter::containString(const QString &searchInString) const
 bool Filter::match(const MessageItem *item) const
 {
     if (!mStatus.isEmpty()) {
-        Q_FOREACH (Akonadi::MessageStatus status, mStatus) {
+        for (Akonadi::MessageStatus status : qAsConst(mStatus)) {
             if (!(status & item->status())) {
                 return false;
             }
@@ -59,12 +59,14 @@ bool Filter::match(const MessageItem *item) const
         if (mMatchingItemIds.contains(item->itemId())) {
             return true;
         }
+
         bool searchMatches = false;
-        if (containString(item->subject())) {
+        bool searchEveryWhere = (mOptions & QuickSearchLine::SearchEveryWhere);
+        if (containString(item->subject()) && ((mOptions &QuickSearchLine::SearchAgainstSubject) || searchEveryWhere)) {
             searchMatches = true;
-        } else if (containString(item->sender())) {
+        } else if (containString(item->sender()) && ((mOptions &QuickSearchLine::SearchAgainstFrom) || searchEveryWhere)) {
             searchMatches = true;
-        } else if (containString(item->receiver())) {
+        } else if (containString(item->receiver()) && ((mOptions &QuickSearchLine::SearchAgainstTo) || searchEveryWhere)) {
             searchMatches = true;
         }
         if (!searchMatches) {
@@ -74,7 +76,7 @@ bool Filter::match(const MessageItem *item) const
 
     if (!mTagId.isEmpty()) {
         //mTagId is a Akonadi::Tag::url
-        const bool tagMatches = item->findTag(mTagId) != Q_NULLPTR;
+        const bool tagMatches = item->findTag(mTagId) != nullptr;
         if (!tagMatches) {
             return false;
         }
@@ -142,7 +144,7 @@ void Filter::setSearchString(const QString &search, QuickSearchLine::SearchOptio
         const QStringList searchListTmp = mSearchString.split(QLatin1Char(' '), QString::SkipEmptyParts);
         mSearchList.clear();
         newStr.clear();
-        Q_FOREACH (const QString &text, searchListTmp) {
+        for (const QString &text : searchListTmp) {
             if (text.size() >= 3) {
                 mSearchList << text;
                 if (!newStr.isEmpty()) {
@@ -182,4 +184,3 @@ void Filter::setSearchString(const QString &search, QuickSearchLine::SearchOptio
     }
     Q_EMIT finished();
 }
-
