@@ -29,7 +29,7 @@
 #include <QGridLayout>
 #include <QPushButton>
 #include <QFrame>
-#include <QHash>
+#include <QMap>
 
 #include <KMessageBox>
 #include <KLocalizedString>
@@ -41,12 +41,8 @@
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
 
-namespace MessageList
-{
-
-namespace Utils
-{
-
+namespace MessageList {
+namespace Utils {
 class ThemeListWidgetItem : public QListWidgetItem
 {
 public:
@@ -55,6 +51,7 @@ public:
     {
         mTheme = new Core::Theme(set);
     }
+
     ~ThemeListWidgetItem()
     {
         delete mTheme;
@@ -64,12 +61,14 @@ public:
     {
         return mTheme;
     }
+
     void forgetTheme()
     {
-        mTheme = Q_NULLPTR;
+        mTheme = nullptr;
     }
+
 private:
-    Core::Theme *mTheme;
+    Core::Theme *mTheme = nullptr;
 };
 
 class ThemeListWidget : public QListWidget
@@ -77,30 +76,30 @@ class ThemeListWidget : public QListWidget
 public:
     ThemeListWidget(QWidget *parent)
         : QListWidget(parent)
-    {}
+    {
+    }
+
 public:
     // need a larger but shorter QListWidget
-    QSize sizeHint() const Q_DECL_OVERRIDE
+    QSize sizeHint() const override
     {
         return QSize(450, 128);
     }
 };
-
 } // namespace Utils
-
 } // namespace MessageList
 
 using namespace MessageList::Core;
 using namespace MessageList::Utils;
 
 ConfigureThemesDialog::ConfigureThemesDialog(QWidget *parent)
-    : QDialog(parent), d(new Private(this))
+    : QDialog(parent)
+    , d(new Private(this))
 {
     setAttribute(Qt::WA_DeleteOnClose);
     setWindowModality(Qt::ApplicationModal);   // FIXME: Sure ?
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -127,8 +126,7 @@ ConfigureThemesDialog::ConfigureThemesDialog(QWidget *parent)
     d->mNewThemeButton->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     g->addWidget(d->mNewThemeButton, 0, 1);
 
-    connect(d->mNewThemeButton, SIGNAL(clicked()),
-            SLOT(newThemeButtonClicked()));
+    connect(d->mNewThemeButton, &QPushButton::clicked, this, [this]() {d->newThemeButtonClicked(); });
 
     d->mCloneThemeButton = new QPushButton(i18n("Clone Theme"), base);
     d->mCloneThemeButton->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
@@ -258,10 +256,10 @@ void ConfigureThemesDialog::Private::editedThemeNameChanged()
 
 void ConfigureThemesDialog::Private::fillThemeList()
 {
-    const QHash< QString, Theme * > &sets = Manager::instance()->themes();
+    const QMap< QString, Theme * > &sets = Manager::instance()->themes();
 
-    QHash< QString, Theme * >::ConstIterator end(sets.constEnd());
-    for (QHash< QString, Theme * >::ConstIterator it = sets.constBegin(); it != end; ++it) {
+    QMap< QString, Theme * >::ConstIterator end(sets.constEnd());
+    for (QMap< QString, Theme * >::ConstIterator it = sets.constBegin(); it != end; ++it) {
         (void)new ThemeListWidgetItem(mThemeList, *(*it));
     }
 }
@@ -272,10 +270,10 @@ void ConfigureThemesDialog::Private::themeListItemClicked(QListWidgetItem *cur)
 
     const int numberOfSelectedItem(mThemeList->selectedItems().count());
 
-    ThemeListWidgetItem *item = cur ? dynamic_cast< ThemeListWidgetItem * >(cur) : Q_NULLPTR;
+    ThemeListWidgetItem *item = cur ? dynamic_cast< ThemeListWidgetItem * >(cur) : nullptr;
     mDeleteThemeButton->setEnabled(item && !item->theme()->readOnly());
     mCloneThemeButton->setEnabled(numberOfSelectedItem == 1);
-    mEditor->editTheme(item ? item->theme() : Q_NULLPTR);
+    mEditor->editTheme(item ? item->theme() : nullptr);
     mExportThemeButton->setEnabled(numberOfSelectedItem > 0);
 
     if (item && !item->isSelected()) {
@@ -296,7 +294,7 @@ ThemeListWidgetItem *ConfigureThemesDialog::Private::findThemeItemById(const QSt
         }
         ++i;
     }
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 ThemeListWidgetItem *ConfigureThemesDialog::Private::findThemeItemByName(const QString &name, Theme *skipTheme)
@@ -314,7 +312,7 @@ ThemeListWidgetItem *ConfigureThemesDialog::Private::findThemeItemByName(const Q
         }
         ++i;
     }
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 ThemeListWidgetItem *ConfigureThemesDialog::Private::findThemeItemByTheme(Theme *set)
@@ -330,7 +328,7 @@ ThemeListWidgetItem *ConfigureThemesDialog::Private::findThemeItemByTheme(Theme
         }
         ++i;
     }
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 QString ConfigureThemesDialog::Private::uniqueNameForTheme(const QString &baseName, Theme *skipTheme)
@@ -345,7 +343,7 @@ QString ConfigureThemesDialog::Private::uniqueNameForTheme(const QString &baseNa
     ThemeListWidgetItem *item = findThemeItemByName(ret, skipTheme);
     while (item) {
         idx++;
-        ret = QStringLiteral("%1 %2").arg(baseName).arg(idx);
+        ret = QStringLiteral("%1 %2").arg(baseName, QString::number(idx));
         item = findThemeItemByName(ret, skipTheme);
     }
     return ret;
@@ -365,11 +363,18 @@ void ConfigureThemesDialog::Private::newThemeButtonClicked()
     ThemeListWidgetItem *item = new ThemeListWidgetItem(mThemeList, emptyTheme);
 
     mThemeList->setCurrentItem(item);
-    mEditor->editTheme(item->theme());
+    Core::Theme *theme = item->theme();
+    if (theme) {
+        mEditor->editTheme(theme);
 
-    mDeleteThemeButton->setEnabled(!item->theme()->readOnly());
-    mExportThemeButton->setEnabled(item);
-    mCloneThemeButton->setEnabled(numberOfSelectedItem == 1);
+        mDeleteThemeButton->setEnabled(!theme->readOnly());
+        mExportThemeButton->setEnabled(item);
+        mCloneThemeButton->setEnabled(numberOfSelectedItem == 1);
+    } else {
+        mDeleteThemeButton->setEnabled(false);
+        mExportThemeButton->setEnabled(false);
+        mCloneThemeButton->setEnabled(false);
+    }
 }
 
 void ConfigureThemesDialog::Private::cloneThemeButtonClicked()
@@ -398,14 +403,14 @@ void ConfigureThemesDialog::Private::cloneThemeButtonClicked()
 
 void ConfigureThemesDialog::Private::deleteThemeButtonClicked()
 {
-    QList<QListWidgetItem *> list = mThemeList->selectedItems();
+    const QList<QListWidgetItem *> list = mThemeList->selectedItems();
     if (list.isEmpty()) {
         return;
     }
     if (KMessageBox::Yes == KMessageBox::questionYesNo(q, list.count() > 1 ? i18n("Do you want to delete selected themes?")
-            : i18n("Do you want to delete \"%1\"?", list.first()->text()), i18nc("@title:window", "Delete Theme"))) {
-        mEditor->editTheme(Q_NULLPTR);   // forget it
-        Q_FOREACH (QListWidgetItem *it, list) {
+                                                       : i18n("Do you want to delete \"%1\"?", list.first()->text()), i18nc("@title:window", "Delete Theme"))) {
+        mEditor->editTheme(nullptr);   // forget it
+        for (QListWidgetItem *it : list) {
             ThemeListWidgetItem *item = dynamic_cast< ThemeListWidgetItem * >(it);
             if (!item) {
                 return;
@@ -458,7 +463,7 @@ void ConfigureThemesDialog::Private::importThemeButtonClicked()
 
 void ConfigureThemesDialog::Private::exportThemeButtonClicked()
 {
-    QList<QListWidgetItem *> list = mThemeList->selectedItems();
+    const QList<QListWidgetItem *> list = mThemeList->selectedItems();
     if (list.isEmpty()) {
         return;
     }
@@ -470,7 +475,7 @@ void ConfigureThemesDialog::Private::exportThemeButtonClicked()
         grp.writeEntry("Count", list.count());
 
         int idx = 0;
-        Q_FOREACH (QListWidgetItem *item, list) {
+        for (QListWidgetItem *item : list) {
             ThemeListWidgetItem *themeItem = static_cast< ThemeListWidgetItem * >(item);
             grp.writeEntry(QStringLiteral("Set%1").arg(idx), themeItem->theme()->saveToString());
             ++idx;
