@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,6 +26,8 @@ public:
     ViewerTest();
 private Q_SLOTS:
     void shouldHaveDefaultValuesOnCreation();
+    void shouldDisplayMessage();
+    void shouldSwitchToAnotherMessage();
 };
 
 #endif // VIEWERTEST_H
