@@ -20,34 +20,24 @@
 #ifndef __MESSAGEVIEWER_DEFAULTRENDERER_H__
 #define __MESSAGEVIEWER_DEFAULTRENDERER_H__
 
-#include <MimeTreeParser/MessagePartRenderer>
+#include <QSharedPointer>
 
-#include<QSharedPointer>
-
-namespace MimeTreeParser
-{
+namespace MimeTreeParser {
 class DefaultRendererPrivate;
-namespace Interface
-{
+class HtmlWriter;
 class MessagePart;
 typedef QSharedPointer<MessagePart> MessagePartPtr;
 }
-}
-
-namespace MessageViewer
-{
 
+namespace MessageViewer {
 class CSSHelperBase;
-class DefaultRendererPrivate;
 
-class DefaultRenderer : public MimeTreeParser::Interface::MessagePartRenderer
+class DefaultRenderer
 {
 public:
-    DefaultRenderer(const MimeTreeParser::Interface::MessagePartPtr &msgPart, CSSHelperBase *cssHelder);
+    DefaultRenderer(const MimeTreeParser::MessagePartPtr &msgPart, CSSHelperBase *cssHelder, MimeTreeParser::HtmlWriter *writer);
     ~DefaultRenderer();
 
-    QString html() const Q_DECL_OVERRIDE;
-
 private:
     MimeTreeParser::DefaultRendererPrivate *d;
 };
