@@ -21,15 +21,12 @@
 #include "scamdetection/scamdetectionwarningwidget.h"
 #include "scamdetection/scamdetectionwebengine.h"
 
-#include <KLocalizedString>
-
 #include <QUrl>
 #include <QStandardPaths>
 #include <QVBoxLayout>
 #include <QPushButton>
 #include <QFileDialog>
 #include <QApplication>
-#include <KAboutData>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QWebEngineView>
@@ -45,16 +42,19 @@ ScamDetectionWebEngineTestWidget::ScamDetectionWebEngineTestWidget(const QString
     lay->addWidget(mScamWarningWidget);
 
     mWebEngineView = new QWebEngineView;
-    connect(mWebEngineView, &QWebEngineView::loadFinished, this, &ScamDetectionWebEngineTestWidget::slotLoadFinished);
+    connect(mWebEngineView, &QWebEngineView::loadFinished, this,
+            &ScamDetectionWebEngineTestWidget::slotLoadFinished);
     lay->addWidget(mWebEngineView);
 
-    connect(mScamDetection, &MessageViewer::ScamDetectionWebEngine::messageMayBeAScam, mScamWarningWidget, &MessageViewer::ScamDetectionWarningWidget::slotShowWarning);
-    connect(mScamWarningWidget, &MessageViewer::ScamDetectionWarningWidget::showDetails, mScamDetection, &MessageViewer::ScamDetectionWebEngine::showDetails);
+    connect(mScamDetection, &MessageViewer::ScamDetectionWebEngine::messageMayBeAScam,
+            mScamWarningWidget, &MessageViewer::ScamDetectionWarningWidget::slotShowWarning);
+    connect(mScamWarningWidget, &MessageViewer::ScamDetectionWarningWidget::showDetails,
+            mScamDetection, &MessageViewer::ScamDetectionWebEngine::showDetails);
 
     mWebEngineView->load(QUrl::fromLocalFile(filename));
 
     QHBoxLayout *hbox = new QHBoxLayout;
-    QPushButton *openFile = new QPushButton(i18n("Open html..."));
+    QPushButton *openFile = new QPushButton(QStringLiteral("Open html..."));
     connect(openFile, &QPushButton::clicked, this, &ScamDetectionWebEngineTestWidget::slotOpenHtml);
     hbox->addWidget(openFile);
     lay->addLayout(hbox);
@@ -71,7 +71,8 @@ void ScamDetectionWebEngineTestWidget::slotLoadFinished()
 
 void ScamDetectionWebEngineTestWidget::slotOpenHtml()
 {
-    const QString fileName = QFileDialog::getOpenFileName(nullptr, QString(), QString(), QStringLiteral("*.html"));
+    const QString fileName = QFileDialog::getOpenFileName(nullptr, QString(),
+                                                          QString(), QStringLiteral("*.html"));
     if (!fileName.isEmpty()) {
         mScamWarningWidget->setVisible(false);
         mWebEngineView->load(QUrl::fromLocalFile(fileName));
@@ -83,23 +84,20 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
 
-    KAboutData aboutData(QStringLiteral("scamdetection_gui"), i18n("ScamDetectionTest_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for scamdetection widget"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[url]"), i18n("URL of an html file to be opened")));
-
-    aboutData.setupCommandLine(&parser);
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[url]"),
+                                        QStringLiteral("URL of an html file to be opened")));
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     QString fileName;
     if (parser.positionalArguments().count()) {
         fileName = parser.positionalArguments().at(0);
     } else {
-        fileName = QFileDialog::getOpenFileName(nullptr, QString(), QString(), i18n("HTML File (*.html)"));
+        fileName
+            = QFileDialog::getOpenFileName(nullptr, QString(), QString(),
+                                           QStringLiteral("HTML File (*.html)"));
     }
     if (fileName.isEmpty()) {
         return 0;
@@ -112,4 +110,3 @@ int main(int argc, char **argv)
     delete w;
     return 0;
 }
-
