@@ -35,11 +35,8 @@
 #include <QPaintDevice>
 #include <QPalette>
 
-namespace MessageViewer
-{
-
-namespace
-{
+namespace MessageViewer {
+namespace {
 // some QColor manipulators that hide the ugly QColor API w.r.t. HSV:
 inline QColor darker(const QColor &c)
 {
@@ -81,7 +78,6 @@ CSSHelperBase::CSSHelperBase(const QPaintDevice *pd)
 
 CSSHelperBase::~CSSHelperBase()
 {
-
 }
 
 void CSSHelperBase::recalculatePGPColors()
@@ -185,7 +181,7 @@ QString CSSHelperBase::quoteFontTag(int level) const
     if (level < 0) {
         level = 0;
     }
-    static const int numQuoteLevels = sizeof mQuoteFont / sizeof * mQuoteFont;
+    static const int numQuoteLevels = 3;
     const int effectiveLevel = mRecycleQuoteColors
                                ? level % numQuoteLevels + 1
                                : qMin(level + 1, numQuoteLevels);
@@ -212,8 +208,7 @@ int CSSHelperBase::fontSize(bool fixed, bool print) const
     return bodyFont(fixed, print).pointSize();
 }
 
-namespace
-{
+namespace {
 int pointsToPixel(const QPaintDevice *pd, int pointSize)
 {
     return (pointSize * pd->logicalDpiY() + 36) / 72;
@@ -225,7 +220,7 @@ static const char *const quoteFontSizes[] = { "85", "80", "75" };
 QString CSSHelperBase::printCssDefinitions(bool fixed) const
 {
     const QString headerFont = QStringLiteral("  font-family: \"%1\" ! important;\n"
-                               "  font-size: %2pt ! important;\n")
+                                              "  font-size: %2pt ! important;\n")
                                .arg(mPrintFont.family())
                                .arg(mPrintFont.pointSize());
     const QPalette &pal = QApplication::palette();
@@ -276,6 +271,9 @@ QString CSSHelperBase::printCssDefinitions(bool fixed) const
                        "div.fancy.header > div a[href] { color: %3 ! important; }\n\n"
 
                        "div.fancy.header > table.outer{\n"
+                       "  all: inherit;\n"
+                       "  width: auto ! important;\n"
+                       "  border-spacing: 0;\n"
                        "  background-color: %2 ! important;\n"
                        "  color: %3 ! important;\n"
                        "  border-bottom: solid %3 1px ! important;\n"
@@ -305,7 +303,7 @@ QString CSSHelperBase::printCssDefinitions(bool fixed) const
                        "div.noprint {\n"
                        "  display:none ! important;\n"
                        "}\n\n"
-                      )
+                       )
         .arg(headerFont,
              pal.color(QPalette::Background).name(),
              pal.color(QPalette::Foreground).name())
@@ -329,6 +327,11 @@ QString CSSHelperBase::quoteCssDefinition() const
                               "  color:transparent;\n"
                               "  font-size:0px;\n"
                               "}\n\n");
+    quoteCSS += QLatin1String(".quotemarksemptyline{\n"
+                              "  color:transparent;\n"
+                              "  font-size:0px;\n"
+                              "  line-height: 12pt;\n"
+                              "}\n\n");
     return quoteCSS;
 }
 
@@ -338,11 +341,12 @@ QString CSSHelperBase::screenCssDefinitions(const CSSHelperBase *helper, bool fi
     const QString bgColor = mBackgroundColor.name();
     const QString linkColor = mLinkColor.name();
     const QString headerFont = QStringLiteral("  font-family: \"%1\" ! important;\n"
-                               "  font-size: %2px ! important;\n")
+                                              "  font-size: %2px ! important;\n")
                                .arg(mBodyFont.family())
                                .arg(pointsToPixel(helper->mPaintDevice, mBodyFont.pointSize()));
-    const QString background =  QStringLiteral("  background-color: %1 ! important;\n").arg(bgColor);
-    const QString bodyFontSize = QString::number(pointsToPixel(helper->mPaintDevice, fontSize(fixed))) + QLatin1String("px");
+    const QString background = QStringLiteral("  background-color: %1 ! important;\n").arg(bgColor);
+    const QString bodyFontSize = QString::number(pointsToPixel(helper->mPaintDevice, fontSize(
+                                                                   fixed))) + QLatin1String("px");
     const QPalette &pal = QApplication::palette();
 
     QString quoteCSS;
@@ -361,15 +365,16 @@ QString CSSHelperBase::screenCssDefinitions(const CSSHelperBase *helper, bool fi
         quoteCSS += QStringLiteral("div.quotelevel%1 {\n"
                                    "  color: %2 ! important;\n")
                     .arg(QString::number(i + 1), quoteColorName(i));
-        if (mQuoteFont[i].italic()) {
+        if (mQuoteFont.italic()) {
             quoteCSS += QLatin1String("  font-style: italic ! important;\n");
         }
-        if (mQuoteFont[i].bold()) {
+        if (mQuoteFont.bold()) {
             quoteCSS += QLatin1String("  font-weight: bold ! important;\n");
         }
-        if (mShrinkQuotes)
+        if (mShrinkQuotes) {
             quoteCSS += QLatin1String("  font-size: ") + QString::fromLatin1(quoteFontSizes[i])
                         + QLatin1String("% ! important;\n");
+        }
         quoteCSS += QLatin1String("}\n\n");
     }
 
@@ -378,10 +383,10 @@ QString CSSHelperBase::screenCssDefinitions(const CSSHelperBase *helper, bool fi
         quoteCSS += QStringLiteral("div.deepquotelevel%1 {\n"
                                    "  color: %2 ! important;\n")
                     .arg(QString::number(i + 1), quoteColorName(i));
-        if (mQuoteFont[i].italic()) {
+        if (mQuoteFont.italic()) {
             quoteCSS += QLatin1String("  font-style: italic ! important;\n");
         }
-        if (mQuoteFont[i].bold()) {
+        if (mQuoteFont.bold()) {
             quoteCSS += QLatin1String("  font-weight: bold ! important;\n");
         }
         if (mShrinkQuotes) {
@@ -564,6 +569,9 @@ QString CSSHelperBase::screenCssDefinitions(const CSSHelperBase *helper, bool fi
                        "}\n\n"
 
                        "div.fancy.header > table.outer {\n"
+                       "  all: inherit;\n"
+                       "  width: auto ! important;\n"
+                       "  border-spacing: 0;\n"
                        "  background-color: %5 ! important;\n"
                        "  color: %4 ! important;\n"
                        "  border-bottom: solid %4 1px ! important;\n"
@@ -575,15 +583,13 @@ QString CSSHelperBase::screenCssDefinitions(const CSSHelperBase *helper, bool fi
                        "  padding: 0px ! important;\n"
                        "  font-size:0.8em ! important;\n"
                        "  border:1px solid %6 ! important;\n"
-                       // FIXME: InfoBackground crashes KHTML
-                       //"  background-color:InfoBackground ! important;\n"
                        "  background-color:%5 ! important;\n"
                        "}\n\n"
 
                        "div.senderstatus{\n"
                        "  text-align:center ! important;\n"
                        "}\n\n"
-                      )
+                       )
 
         .arg(headerFont)
         .arg(pal.color(QPalette::Highlight).name(),
@@ -598,7 +604,7 @@ QString CSSHelperBase::commonCssDefinitions() const
 {
     const QPalette &pal = QApplication::palette();
     const QString headerFont = QStringLiteral("font-family: \"%1\" ! important;\n"
-                               "  font-size: %2px ! important;\n")
+                                              "  font-size: %2px ! important;\n")
                                .arg(mBodyFont.family())
                                .arg(pointsToPixel(this->mPaintDevice, mBodyFont.pointSize()));
 
@@ -714,8 +720,10 @@ QString CSSHelperBase::commonCssDefinitions() const
                        "div.quotelevelmark {\n"
                        "  position: absolute;\n"
                        "  margin-left:-10px;\n"
-                       "}\n\n").arg(pal.color(QPalette::Background).name()).arg(pal.color(QPalette::Foreground).name()).arg(headerFont)
-        ;
+                       "}\n\n").arg(pal.color(QPalette::Background).name()).arg(pal.color(QPalette::
+                                                                                          Foreground).name())
+        .arg(headerFont)
+    ;
 }
 
 void CSSHelperBase::setBodyFont(const QFont &font)
@@ -743,5 +751,4 @@ QColor CSSHelperBase::pgpWarnColor() const
 {
     return cPgpWarnH;
 }
-
 }
