@@ -19,10 +19,8 @@
 #ifndef TESTWEBENGINEACCESSKEY_H
 #define TESTWEBENGINEACCESSKEY_H
 
-#include <QWebEngineView>
 #include <QWidget>
-namespace WebEngineViewer
-{
+namespace WebEngineViewer {
 class MailWebEngineView;
 }
 
