@@ -26,15 +26,13 @@ class MessageViewer::ViewerPluginInterfacePrivate
 public:
     ViewerPluginInterfacePrivate()
     {
-
     }
 };
 
 ViewerPluginInterface::ViewerPluginInterface(QObject *parent)
-    : QObject(parent),
-      d(new MessageViewer::ViewerPluginInterfacePrivate)
+    : QObject(parent)
+    , d(new MessageViewer::ViewerPluginInterfacePrivate)
 {
-
 }
 
 ViewerPluginInterface::~ViewerPluginInterface()
@@ -77,6 +75,12 @@ void ViewerPluginInterface::setMessageItem(const Akonadi::Item &item)
     // Reimplement in subclass
 }
 
+void ViewerPluginInterface::setCurrentCollection(const Akonadi::Collection &col)
+{
+    Q_UNUSED(col);
+    // Reimplement in subclass
+}
+
 void ViewerPluginInterface::closePlugin()
 {
     // Reimplement in subclass
