@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2011-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2011-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,18 +21,9 @@
 #include "templateparser_export.h"
 
 class QString;
-class QStringList;
-namespace TemplateParser
-{
-
-namespace Util
-{
-
+namespace TemplateParser {
+namespace Util {
 TEMPLATEPARSER_EXPORT void deleteTemplate(const QString &id);
-
-QStringList keywords();
-QStringList keywordsWithArgs();
-QStringList keywordsWithArgsForCompleter();
 }
 }
 
